@@ -3,7 +3,7 @@ from sleepyask.openai.chatgpt import ask_questions
 import traceback
 import logging
 
-def ask(configs : list, questions : list, output_file_path : str, verbose: bool = False):
+def ask(configs : list, questions : list, output_file_path : str, verbose: bool = False, model : str = "gpt-3.5-turbo"):
     '''
     `config` should be a list containing your ChatGPT access tokens / email and password\n
     `questions` should contain a list of questions you would like ChatGPT to answer.\n
@@ -11,11 +11,11 @@ def ask(configs : list, questions : list, output_file_path : str, verbose: bool
     '''
     if not isinstance(questions, list): raise ValueError("[questions] should be a list")
     def func() -> None:
-        try: ask_questions(configs=configs, questions=questions, output_file_path=output_file_path, verbose=verbose)
+        try: ask_questions(configs=configs, questions=questions, output_file_path=output_file_path, verbose=verbose, model=model)
         except Exception as e: logging.error(traceback.format_exc())
     
     schedule.every(15).minutes.do(func)
     schedule.every(15).minutes.do(func)
 
     func()
-    while True: schedule.run_pending()
\ No newline at end of file
+    while True: schedule.run_pending()
